==> 0.1.9.tar.gz: example/showcase/showcase.dart <==

library tags.showcase;

import 'dart:html';
import 'package:tags/tags.dart';

main() {  
  document.body.append(
      div(() {
        h1()..text = 'HTML Tags Showcase.';
        h2()..text = 'Text:';
        p(() {
          text('Lorem ipsum dolor sit amet,');
          b()..text = ' consectetur adipisicing elit, sed do ';
          text('eiusmod tempor incididunt ut labore et dolore magna aliqua.');
          i()..text = '  Ut enim ad minim veniam, quis nostrud exercitation ';
          text('ullamco laboris nisi ut aliquip ex ea commodo consequat.');
          u()..text = '  Duis aute irure dolor in reprehenderit in ';
          text('voluptate velit esse cillum dolore ');
          del()..text = 'eu fugiat nulla pariatur.';
        });
        h2()..text = 'Tables:';
        table(() {
          thead(() {
            tr(() {
              th()..text = 'First';
              th()..text = 'Last';
              th()..text = 'Age';
            });
          });
          tbody(() {      
            tr(() {
              td()..text = 'Jill';
              td()..text = 'Smith';
              td()..text = '29';
            });
            tr(() {
              td()..text = 'John';
              td()..text = 'Smith';
              td()..text = '33';
            });
          });
        })..border = '1';
        h2()..text = 'Lists:';
        h3()..text = 'Unordered:';
        ul(() {
          li()..text = 'Coffee';
          li()..text = 'Tea';
          li()..text = 'Milk';
        });
        h3()..text = 'Ordered:';
        ol(() {
          li()..text = 'One';
          li()..text = 'Two';
          li()..text = 'Three';
        });        
        h3()..text = 'Definition:';
        dl(() {
          dt()..text = 'Coffee';
          dd()..text = 'Black hot drink';
          dt()..text = 'Milk';
          dd()..text = 'White cold drink';
        });
        h2()..text = 'Custom Tags:';
        h3()..text = 'Toggle Button:';
        toggleButton(() {
          span()..text = 'up'..classes = ['up'];
          span()..text = 'down'..classes = ['down'];
        });
        h3()..text = 'Toggle Open:';
        toggleOpen(() {
          a()..text = 'File'..classes = ['toggle'];
          ul(() {
            li(() => a()..href=''..text = 'New');
            li(() => a()..href=''..text = 'Open');
          })..classes = ['open'];
        });
      }));
}

==> 0.2.0.tar.gz: example/showcase/showcase.dart <==

library tags.showcase;

import 'dart:html';
import 'package:tags/tags.dart';

main() {  
  document.body.append(
      div(() {
        h1()..text = 'HTML Tags Showcase.';
        h2()..text = 'Text:';
        p(() {
          appendText('Lorem ipsum dolor sit amet,');
          b()..text = ' consectetur adipisicing elit, sed do ';
          appendText('eiusmod tempor incididunt ut labore et dolore magna.');
          i()..text = '  Ut enim ad minim veniam, quis nostrud exercitation ';
          appendText('ullamco laboris nisi ut aliquip ex commodo consequat.');
          u()..text = '  Duis aute irure dolor in reprehenderit in ';
          appendText('voluptate velit esse cillum dolore ');
          del()..text = 'eu fugiat nulla pariatur.';
        });
        h2()..text = 'Code:';
        pre(() {
          code()..text = 'abstract class Awesome {}';
        });
        h2()..text = 'Tables:';
        table(() {
          thead(() {
            tr(() {
              th()..text = 'First';
              th()..text = 'Last';
              th()..text = 'Age';
            });
          });
          tbody(() {      
            tr(() {
              td()..text = 'Jill';
              td()..text = 'Smith';
              td()..text = '29';
            });
            tr(() {
              td()..text = 'John';
              td()..text = 'Smith';
              td()..text = '33';
            });
          });
        })..border = '1';
        h2()..text = 'Lists:';
        h3()..text = 'Unordered:';
        ul(() {
          li()..text = 'Coffee';
          li()..text = 'Tea';
          li()..text = 'Milk';
        });
        h3()..text = 'Ordered:';
        ol(() {
          li()..text = 'One';
          li()..text = 'Two';
          li()..text = 'Three';
        });        
        h3()..text = 'Definition:';
        dl(() {
          dt()..text = 'Coffee';
          dd()..text = 'Black hot drink';
          dt()..text = 'Milk';
          dd()..text = 'White cold drink';
        });
        h2()..text = 'Custom Tags:';
        h3()..text = 'Toggle Button:';
        toggleButton(() {
          span()..text = 'up'..classes = ['up'];
          span()..text = 'down'..classes = ['down'];
        });
        h3()..text = 'Toggle Open:';
        toggleOpen(() {
          a()..text = 'File'..classes = ['toggle'];
          ul(() {
            li(() => a()..href=''..text = 'New');
            li(() => a()..href=''..text = 'Open');
          })..classes = ['open'];
        });
      }));
}
